==> libgda-0.2.10.tar.gz: libgda-0.2.10/providers/gda-default-server/main-default.c <==
/* GDA Default Provider
 * Copyright (C) 2001 The Free Software Foundation
 *
 * AUTHORS:
 *	Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gda-default.h"

static GdaServerImpl*         server_impl = NULL;
static GdaServerImplFunctions server_impl_functions = {
	gda_default_connection_new,
	gda_default_connection_open,
	gda_default_connection_close,
	gda_default_connection_begin_transaction,
	gda_default_connection_commit_transaction,
	gda_default_connection_rollback_transaction,
	gda_default_connection_open_schema,
	gda_default_connection_modify_schema,
	gda_default_connection_start_logging,
	gda_default_connection_stop_logging,
	gda_default_connection_create_table,
	gda_default_connection_supports,
	gda_default_connection_get_gda_type,
	gda_default_connection_get_c_type,
	gda_default_connection_sql2xml,
	gda_default_connection_xml2sql,
	gda_default_connection_free,

	gda_default_command_new,
	gda_default_command_execute,
	gda_default_command_free,

	gda_default_recordset_new,
	gda_default_recordset_move_next,
	gda_default_recordset_move_prev,
	gda_default_recordset_close,
	gda_default_recordset_free,

	gda_default_error_make
};

gint
main (gint argc, gchar *argv[])
{
	/* initialize CORBA stuff */
	gda_server_init("gda-default-srv", VERSION, argc, argv);

	/* register the server implementation */
	server_impl = gda_server_impl_new("OAFIID:GNOME_GDA_Provider_Default_ConnectionFactory",
									  &server_impl_functions);
	if (server_impl) {
		gda_server_impl_start(server_impl);
    }
	else gda_log_error(_("Could not register Default provider implementation"));
	return 0;
}

==> libgda-0.2.91.tar.gz: libgda-0.2.91/providers/gda-default-server/main-default.c <==
/* GDA Default Provider
 * Copyright (C) 2001 The Free Software Foundation
 *
 * AUTHORS:
 *	Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gda-default.h"

static GdaServer*             server_impl = NULL;
static GdaServerImplFunctions server_impl_functions = {
	gda_default_connection_new,
	gda_default_connection_open,
	gda_default_connection_close,
	gda_default_connection_begin_transaction,
	gda_default_connection_commit_transaction,
	gda_default_connection_rollback_transaction,
	gda_default_connection_open_schema,
	gda_default_connection_modify_schema,
	gda_default_connection_start_logging,
	gda_default_connection_stop_logging,
	gda_default_connection_create_table,
	gda_default_connection_supports,
	gda_default_connection_get_gda_type,
	gda_default_connection_get_c_type,
	gda_default_connection_sql2xml,
	gda_default_connection_xml2sql,
	gda_default_connection_free,

	gda_default_command_new,
	gda_default_command_execute,
	gda_default_command_free,

	gda_default_recordset_new,
	gda_default_recordset_move_next,
	gda_default_recordset_move_prev,
	gda_default_recordset_close,
	gda_default_recordset_free,

	gda_default_error_make
};

gint
main (gint argc, gchar *argv[])
{
	/* initialize CORBA stuff */
	gda_server_init("gda-default-srv", VERSION, argc, argv);

	/* register the server implementation */
	server_impl = gda_server_new("OAFIID:GNOME_GDA_Provider_Default_ConnectionFactory",
				  &server_impl_functions);
	if (server_impl) {
		gda_server_start(server_impl);
    }
	else gda_log_error(_("Could not register Default provider implementation"));
	return 0;
}
